@@ -21,7 +21,7 @@ from sklearn.metrics import precision_score
 from sklearn.metrics import recall_score
 from sklearn.metrics import accuracy_score
 from sklearn.metrics import f1_score
-from tqdm import tqdm
+from tqdm.autonotebook import tqdm
 
 __author__ = "Sergio Peignier, Pauline Schmitt"
 __copyright__ = "Copyright 2019, The GReNaDIne Project"
@@ -71,10 +71,10 @@ def jaccard_similarity(joined_ranks, k):
     jaccard_sim = pd.DataFrame(columns=joined_ranks.columns,
                                index=joined_ranks.columns)
     methods = list(jaccard_sim.columns)
-    for i,c in enumerate(methods[:-1]):
-        top_k_c = list(joined_ranks[c].sort_values().index)[:k]
+    for i,c in enumerate(tqdm(methods[:-1])):
+        top_k_c = list(joined_ranks[c].nsmallest(k).index)
         for j,b in enumerate(methods[i+1:]):
-            top_k_i = list(joined_ranks[b].sort_values().index)[:k]
+            top_k_i = list(joined_ranks[b].nsmallest(k).index)
             inter = len(set(top_k_i).intersection(set(top_k_c)))
             union = len(set(top_k_i).union(set(top_k_c)))
             jaccard_sim.loc[b,c] = inter/union
@@ -104,7 +104,7 @@ def get_top_k_edges(method_ranks,k):
         ['gene1_gene2', 'gene3_gene1']
 
     """
-    return list(method_ranks.sort_values().index)[:k]
+    return list(method_ranks.nsmallest(k).index)[:k]
 
 def get_top_k_edges_per_node(method_ranks,k,tg=1):
     """
@@ -257,6 +257,7 @@ def pca_representation(joined_ranks,k,**pca_parameters):
     Returns:
         pandas.DataFrame: methods coordinates along principal components, where
         rows represent methods and columns representt Principal Components.
+        sklearn.decomposition.PCA: sklearn pca object
 
     Example:
         >>> import pandas as pd
@@ -268,9 +269,9 @@ def pca_representation(joined_ranks,k,**pca_parameters):
                                                'gene1_gene3',
                                                'gene3_gene2',
                                                'gene3_gene1'])
-        >>> pca = pca_representation(joined_ranks, k=2)
+        >>> pca_X, pca = pca_representation(joined_ranks, k=2)
         [9.81125224e-01 1.88747757e-02 1.60366056e-32]
-        >>> pca
+        >>> pca_X
                         0         1             2
         method1 -1.400804 -0.194292  1.790900e-16
         method2 -0.512730  0.265408  1.790900e-16
@@ -288,8 +289,7 @@ def pca_representation(joined_ranks,k,**pca_parameters):
     rankingsT_pca = pca.fit_transform(rankingsT)
     rankingsT_pca = pd.DataFrame(rankingsT_pca)
     rankingsT_pca.index = rankingsT.index
-    print(pca.explained_variance_ratio_)
-    return(rankingsT_pca)
+    return(rankingsT_pca,pca)
 
 def edges2boolvec(total_edges, chosen_edges):
     """
