@@ -17,6 +17,7 @@ from sklearn.ensemble import ExtraTreesRegressor as _sklearn_ExtraTreesRegressor
 from sklearn.ensemble import GradientBoostingRegressor as _sklearn_GradientBoostingRegressor
 from sklearn.ensemble import AdaBoostRegressor as _sklearn_AdaBoostRegressor
 from sklearn.ensemble import BaggingRegressor as _sklearn_BaggingRegressor
+from pandas import DataFrame
 import numpy as np
 try:
     from sklearn.linear_model import RandomizedLasso as _sklearn_RandomizedLasso
@@ -244,7 +245,7 @@ def Lasso_score(X,y,**l1_parameters):
     """
     regressor = _sklearn_Lasso(**l1_parameters)
     regressor.fit(X, y)
-    scores = np.np.abs(regressor.coef_)
+    scores = np.abs(regressor.coef_)
     return(scores)
 
 def LassoLars_score(X,y,**l1_parameters):
@@ -467,7 +468,7 @@ def bagging_regressor(X, y, **bagging_parameters):
     def get_score(classifier):
         scores=None
         if hasattr(classifier, 'feature_importances_'):
-            scores = pd.DataFrame(feature_importances).mean(axis=0)
+            scores = DataFrame(feature_importances).mean(axis=0)
         elif hasattr(classifier,"coef_"):
             scores = np.abs(classifier.coef_).flatten()
         return(scores)
@@ -476,7 +477,7 @@ def bagging_regressor(X, y, **bagging_parameters):
     coefs = [get_score(e) for e in bc.estimators_]
     coefs = [c for c in coefs if c is not None]
     if len(coefs):
-        scores = pd.DataFrame(coefs).mean(axis=0)
+        scores = DataFrame(coefs).mean(axis=0)
     else:
         print("Base regressor has not a feature_importance of coef_ attribute")
         return(0)
